# core/dbt directory README

## The following are individual files in this directory.

### compilation.py

### constants.py

### dataclass_schema.py

### deprecations.py

### exceptions.py

### flags.py

### helper_types.py

### hooks.py

### lib.py

### links.py

### main.py

### node_types.py

### profiler.py

### selected_resources.py

### semver.py

### tracking.py

### ui.py

### utils.py

### version.py


## The subdirectories will be documented in a README in the subdirectory
* adapters
* cli
* clients
* config
* context
* contracts
* deps
* docs
* events
* graph
* include
* parser
* task
* tests
